@@ -5,6 +5,11 @@
 
 #include <X11/extensions/Xrandr.h>
 
+#define MINIMUM_LOGICAL_SCALE_FACTOR 0.74f
+#define MAXIMUM_LOGICAL_SCALE_FACTOR 2.0f
+#define MINIMUM_GLOBAL_SCALE_FACTOR 1
+#define MAXIMUM_GLOBAL_SCALE_FACTOR 2
+
 typedef struct ScreenInfo ScreenInfo;
 
 struct ScreenInfo
@@ -35,6 +40,7 @@ struct GnomeRRScreenPrivate
     Screen *			xscreen;
     Window			xroot;
     ScreenInfo *		info;
+    GSettings *         interface_settings;
     
     int				randr_event_base;
     int				rr_major_version;
@@ -51,7 +57,7 @@ struct GnomeRROutputInfoPrivate
     gboolean		on;
     int			width;
     int			height;
-    int			rate;
+    double		rate;
     int			x;
     int			y;
     GnomeRRRotation	rotation;
@@ -65,6 +71,10 @@ struct GnomeRROutputInfoPrivate
     int			pref_height;
     char *		display_name;
     gboolean            primary;
+    float       scale;
+    gboolean    doublescan;
+    gboolean    interlaced;
+    gboolean    vsync;
 };
 
 struct GnomeRRConfigPrivate
@@ -72,6 +82,8 @@ struct GnomeRRConfigPrivate
   gboolean clone;
   GnomeRRScreen *screen;
   GnomeRROutputInfo **outputs;
+  guint base_scale;
+  gboolean auto_scale;
 };
 
 gboolean _gnome_rr_output_name_is_laptop (const char *name);
